#
# PySNMP MIB module Q-BRIDGE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/Q-BRIDGE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:25:16 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ConstraintsIntersection, ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint")
( dot1dBasePortEntry, dot1dBasePort, dot1dBridge, ) = mibBuilder.importSymbols("BRIDGE-MIB", "dot1dBasePortEntry", "dot1dBasePort", "dot1dBridge")
( EnabledStatus, ) = mibBuilder.importSymbols("P-BRIDGE-MIB", "EnabledStatus")
( TimeFilter, ) = mibBuilder.importSymbols("RMON2-MIB", "TimeFilter")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( Counter64, iso, MibIdentifier, ModuleIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, Gauge32, TimeTicks, IpAddress, NotificationType, Unsigned32, Integer32, ObjectIdentity, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "iso", "MibIdentifier", "ModuleIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "Gauge32", "TimeTicks", "IpAddress", "NotificationType", "Unsigned32", "Integer32", "ObjectIdentity", "Bits")
( DisplayString, MacAddress, TruthValue, RowStatus, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "MacAddress", "TruthValue", "RowStatus", "TextualConvention")
qBridgeMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 17, 7)).setRevisions(("2006-01-09 00:00", "1999-08-25 00:00",))
if mibBuilder.loadTexts: qBridgeMIB.setLastUpdated('200601090000Z')
if mibBuilder.loadTexts: qBridgeMIB.setOrganization('IETF Bridge MIB Working Group')
if mibBuilder.loadTexts: qBridgeMIB.setContactInfo('Email:  Bridge-mib@ietf.org\n                 ietfmibs@ops.ietf.org\n\n                 David Levi\n         Postal: Nortel Networks\n                 4655 Great America Parkway\n                 Santa Clara, CA 95054\n                 USA\n         Phone:  +1 865 686 0432\n         Email:  dlevi@nortel.com\n\n                 David Harrington\n         Postal: Effective Software\n                 50 Harding Rd.\n                 Portsmouth, NH 03801\n                 USA\n         Phone:  +1 603 436 8634\n         Email:  ietfdbh@comcast.net\n                 Les Bell\n         Postal: Hemel Hempstead, Herts. HP2 7YU\n                 UK\n          Email: elbell@ntlworld.com\n\n                 Andrew Smith\n         Postal: Beijing Harbour Networks\n                 Jiuling Building\n                 21 North Xisanhuan Ave.\n                 Beijing, 100089\n                 PRC\n            Fax: +1 415 345 1827\n          Email: ah_smith@acm.org\n\n                 Paul Langille\n         Postal: Newbridge Networks\n                 5 Corporate Drive\n                 Andover, MA 01810\n                 USA\n          Phone: +1 978 691 4665\n          Email: langille@newbridge.com\n\n                 Anil Rijhsinghani\n         Postal: Accton Technology Corporation\n                 5 Mount Royal Ave\n                 Marlboro, MA 01752\n                 USA\n          Phone:\n          Email: anil@accton.com\n\n                 Keith McCloghrie\n         Postal: Cisco Systems, Inc.\n                 170 West Tasman Drive\n                 San Jose, CA 95134-1706\n                 USA\n          Phone: +1 408 526 5260\n          Email: kzm@cisco.com')
if mibBuilder.loadTexts: qBridgeMIB.setDescription('The VLAN Bridge MIB module for managing Virtual Bridged\n        Local Area Networks, as defined by IEEE 802.1Q-2003,\n        including Restricted Vlan Registration defined by\n        IEEE 802.1u-2001 and Vlan Classification defined by\n        IEEE 802.1v-2001.\n\n        Copyright (C) The Internet Society (2006).  This version of\n        this MIB module is part of RFC 4363; See the RFC itself for\n        full legal notices.')
qBridgeMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 1))
class PortList(OctetString, TextualConvention):
    pass

class VlanIndex(Unsigned32, TextualConvention):
    displayHint = 'd'

class VlanId(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(1,4094)

class VlanIdOrAny(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(ValueRangeConstraint(1,4094),ValueRangeConstraint(4095,4095),)
class VlanIdOrNone(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(1,4094),)
class VlanIdOrAnyOrNone(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(1,4094),ValueRangeConstraint(4095,4095),)
dot1qBase = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 1, 1))
dot1qTp = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 1, 2))
dot1qStatic = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 1, 3))
dot1qVlan = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 1, 4))
dot1vProtocol = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 1, 5))
dot1qVlanVersionNumber = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1,))).clone(namedValues=NamedValues(("version1", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qVlanVersionNumber.setDescription('The version number of IEEE 802.1Q that this device\n        supports.')
dot1qMaxVlanId = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 1, 2), VlanId()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qMaxVlanId.setDescription('The maximum IEEE 802.1Q VLAN-ID that this device\n        supports.')
dot1qMaxSupportedVlans = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qMaxSupportedVlans.setDescription('The maximum number of IEEE 802.1Q VLANs that this\n        device supports.')
dot1qNumVlans = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qNumVlans.setDescription('The current number of IEEE 802.1Q VLANs that are\n        configured in this device.')
dot1qGvrpStatus = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 1, 5), EnabledStatus()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qGvrpStatus.setDescription('The administrative status requested by management for\n        GVRP.  The value enabled(1) indicates that GVRP should\n        be enabled on this device, on all ports for which it has\n        not been specifically disabled.  When disabled(2), GVRP\n        is disabled on all ports, and all GVRP packets will be\n        forwarded transparently.  This object affects all GVRP\n        Applicant and Registrar state machines.  A transition\n        from disabled(2) to enabled(1) will cause a reset of all\n        GVRP state machines on all ports.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qFdbTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 1), )
if mibBuilder.loadTexts: dot1qFdbTable.setDescription('A table that contains configuration and control\n        information for each Filtering Database currently\n        operating on this device.  Entries in this table appear\n        automatically when VLANs are assigned FDB IDs in the\n        dot1qVlanCurrentTable.')
dot1qFdbEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 1, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qFdbId"))
if mibBuilder.loadTexts: dot1qFdbEntry.setDescription('Information about a specific Filtering Database.')
dot1qFdbId = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 1, 1, 1), Unsigned32())
if mibBuilder.loadTexts: dot1qFdbId.setDescription('The identity of this Filtering Database.')
dot1qFdbDynamicCount = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qFdbDynamicCount.setDescription('The current number of dynamic entries in this\n        Filtering Database.')
dot1qTpFdbTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 2), )
if mibBuilder.loadTexts: dot1qTpFdbTable.setDescription('A table that contains information about unicast entries\n        for which the device has forwarding and/or filtering\n        information.  This information is used by the\n        transparent bridging function in determining how to\n        propagate a received frame.')
dot1qTpFdbEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 2, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qFdbId"), (0, "Q-BRIDGE-MIB", "dot1qTpFdbAddress"))
if mibBuilder.loadTexts: dot1qTpFdbEntry.setDescription('Information about a specific unicast MAC address for\n        which the device has some forwarding and/or filtering\n        information.')
dot1qTpFdbAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 2, 1, 1), MacAddress())
if mibBuilder.loadTexts: dot1qTpFdbAddress.setDescription('A unicast MAC address for which the device has\n        forwarding and/or filtering information.')
dot1qTpFdbPort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpFdbPort.setDescription("Either the value '0', or the port number of the port on\n        which a frame having a source address equal to the value\n        of the corresponding instance of dot1qTpFdbAddress has\n        been seen.  A value of '0' indicates that the port\n        number has not been learned but that the device does\n        have some forwarding/filtering information about this\n        address (e.g., in the dot1qStaticUnicastTable).\n        Implementors are encouraged to assign the port value to\n        this object whenever it is learned, even for addresses\n        for which the corresponding value of dot1qTpFdbStatus is\n        not learned(3).")
dot1qTpFdbStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("invalid", 2), ("learned", 3), ("self", 4), ("mgmt", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpFdbStatus.setDescription("The status of this entry.  The meanings of the values\n        are:\n            other(1) - none of the following.  This may include\n                the case where some other MIB object (not the\n                corresponding instance of dot1qTpFdbPort, nor an\n                entry in the dot1qStaticUnicastTable) is being\n                used to determine if and how frames addressed to\n                the value of the corresponding instance of\n                dot1qTpFdbAddress are being forwarded.\n            invalid(2) - this entry is no longer valid (e.g., it\n                was learned but has since aged out), but has not\n                yet been flushed from the table.\n            learned(3) - the value of the corresponding instance\n                of dot1qTpFdbPort was learned and is being used.\n            self(4) - the value of the corresponding instance of\n                dot1qTpFdbAddress represents one of the device's\n                addresses.  The corresponding instance of\n                dot1qTpFdbPort indicates which of the device's\n                ports has this address.\n            mgmt(5) - the value of the corresponding instance of\n                dot1qTpFdbAddress is also the value of an\n                existing instance of dot1qStaticAddress.")
dot1qTpGroupTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 3), )
if mibBuilder.loadTexts: dot1qTpGroupTable.setDescription('A table containing filtering information for VLANs\n        configured into the bridge by (local or network)\n        management, or learned dynamically, specifying the set of\n        ports to which frames received on a VLAN for this FDB\n        and containing a specific Group destination address are\n        allowed to be forwarded.')
dot1qTpGroupEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 3, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qVlanIndex"), (0, "Q-BRIDGE-MIB", "dot1qTpGroupAddress"))
if mibBuilder.loadTexts: dot1qTpGroupEntry.setDescription('Filtering information configured into the bridge by\n        management, or learned dynamically, specifying the set of\n        ports to which frames received on a VLAN and containing\n        a specific Group destination address are allowed to be\n        forwarded.  The subset of these ports learned dynamically\n        is also provided.')
dot1qTpGroupAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 3, 1, 1), MacAddress())
if mibBuilder.loadTexts: dot1qTpGroupAddress.setDescription("The destination Group MAC address in a frame to which\n        this entry's filtering information applies.")
dot1qTpGroupEgressPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 3, 1, 2), PortList()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpGroupEgressPorts.setDescription('The complete set of ports, in this VLAN, to which\n        frames destined for this Group MAC address are currently\n        being explicitly forwarded.  This does not include ports\n        for which this address is only implicitly forwarded, in\n        the dot1qForwardAllPorts list.')
dot1qTpGroupLearnt = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 3, 1, 3), PortList()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpGroupLearnt.setDescription('The subset of ports in dot1qTpGroupEgressPorts that\n        were learned by GMRP or some other dynamic mechanism, in\n        this Filtering database.')
dot1qForwardAllTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 4), )
if mibBuilder.loadTexts: dot1qForwardAllTable.setDescription('A table containing forwarding information for each\n        VLAN, specifying the set of ports to which forwarding of\n        all multicasts applies, configured statically by\n        management or dynamically by GMRP.  An entry appears in\n        this table for all VLANs that are currently\n        instantiated.')
dot1qForwardAllEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 4, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qVlanIndex"))
if mibBuilder.loadTexts: dot1qForwardAllEntry.setDescription('Forwarding information for a VLAN, specifying the set\n        of ports to which all multicasts should be forwarded,\n        configured statically by management or dynamically by\n        GMRP.')
dot1qForwardAllPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 4, 1, 1), PortList()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qForwardAllPorts.setDescription('The complete set of ports in this VLAN to which all\n        multicast group-addressed frames are to be forwarded.\n        This includes ports for which this need has been\n        determined dynamically by GMRP, or configured statically\n        by management.')
dot1qForwardAllStaticPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 4, 1, 2), PortList()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qForwardAllStaticPorts.setDescription('The set of ports configured by management in this VLAN\n        to which all multicast group-addressed frames are to be\n        forwarded.  Ports entered in this list will also appear\n        in the complete set shown by dot1qForwardAllPorts.  This\n        value will be restored after the device is reset.  This\n        only applies to ports that are members of the VLAN,\n        defined by dot1qVlanCurrentEgressPorts.  A port may not\n        be added in this set if it is already a member of the\n        set of ports in dot1qForwardAllForbiddenPorts.  The\n        default value is a string of ones of appropriate length,\n        to indicate the standard behaviour of using basic\n        filtering services, i.e., forward all multicasts to all\n        ports.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qForwardAllForbiddenPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 4, 1, 3), PortList()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qForwardAllForbiddenPorts.setDescription('The set of ports configured by management in this VLAN\n        for which the Service Requirement attribute Forward All\n        Multicast Groups may not be dynamically registered by\n        GMRP.  This value will be restored after the device is\n        reset.  A port may not be added in this set if it is\n        already a member of the set of ports in\n        dot1qForwardAllStaticPorts.  The default value is a\n        string of zeros of appropriate length.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qForwardUnregisteredTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 5), )
if mibBuilder.loadTexts: dot1qForwardUnregisteredTable.setDescription('A table containing forwarding information for each\n        VLAN, specifying the set of ports to which forwarding of\n        multicast group-addressed frames for which no\n        more specific forwarding information applies.  This is\n        configured statically by management and determined\n        dynamically by GMRP.  An entry appears in this table for\n        all VLANs that are currently instantiated.')
dot1qForwardUnregisteredEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 5, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qVlanIndex"))
if mibBuilder.loadTexts: dot1qForwardUnregisteredEntry.setDescription('Forwarding information for a VLAN, specifying the set\n        of ports to which all multicasts for which there is no\n        more specific forwarding information shall be forwarded.\n        This is configured statically by management or\n        dynamically by GMRP.')
dot1qForwardUnregisteredPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 5, 1, 1), PortList()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qForwardUnregisteredPorts.setDescription('The complete set of ports in this VLAN to which\n        multicast group-addressed frames for which there is no\n        more specific forwarding information will be forwarded.\n        This includes ports for which this need has been\n        determined dynamically by GMRP, or configured statically\n        by management.')
dot1qForwardUnregisteredStaticPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 5, 1, 2), PortList()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qForwardUnregisteredStaticPorts.setDescription('The set of ports configured by management, in this\n        VLAN, to which multicast group-addressed frames for\n        which there is no more specific forwarding information\n        are to be forwarded.  Ports entered in this list will\n        also appear in the complete set shown by\n        dot1qForwardUnregisteredPorts.  This value will be\n        restored after the device is reset.  A port may not be\n        added in this set if it is already a member of the set\n        of ports in dot1qForwardUnregisteredForbiddenPorts.  The\n        default value is a string of zeros of appropriate\n        length, although this has no effect with the default\n        value of dot1qForwardAllStaticPorts.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qForwardUnregisteredForbiddenPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 2, 5, 1, 3), PortList()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qForwardUnregisteredForbiddenPorts.setDescription('The set of ports configured by management in this VLAN\n        for which the Service Requirement attribute Forward\n        Unregistered Multicast Groups may not be dynamically\n        registered by GMRP.  This value will be restored after\n        the device is reset.  A port may not be added in this\n        set if it is already a member of the set of ports in\n        dot1qForwardUnregisteredStaticPorts.  The default value\n        is a string of zeros of appropriate length.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qStaticUnicastTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 1), )
if mibBuilder.loadTexts: dot1qStaticUnicastTable.setDescription('A table containing filtering information for Unicast\n        MAC addresses for each Filtering Database, configured\n        into the device by (local or network) management\n        specifying the set of ports to which frames received\n        from specific ports and containing specific unicast\n        destination addresses are allowed to be forwarded.  A\n        value of zero in this table (as the port number from\n        which frames with a specific destination address are\n        received) is used to specify all ports for which there\n        is no specific entry in this table for that particular\n        destination address.  Entries are valid for unicast\n        addresses only.')
dot1qStaticUnicastEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 1, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qFdbId"), (0, "Q-BRIDGE-MIB", "dot1qStaticUnicastAddress"), (0, "Q-BRIDGE-MIB", "dot1qStaticUnicastReceivePort"))
if mibBuilder.loadTexts: dot1qStaticUnicastEntry.setDescription('Filtering information configured into the device by\n        (local or network) management specifying the set of\n        ports to which frames received from a specific port and\n        containing a specific unicast destination address are\n        allowed to be forwarded.')
dot1qStaticUnicastAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 1, 1, 1), MacAddress())
if mibBuilder.loadTexts: dot1qStaticUnicastAddress.setDescription("The destination MAC address in a frame to which this\n        entry's filtering information applies.  This object must\n        take the value of a unicast address.")
dot1qStaticUnicastReceivePort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)))
if mibBuilder.loadTexts: dot1qStaticUnicastReceivePort.setDescription("Either the value '0' or the port number of the port\n        from which a frame must be received in order for this\n        entry's filtering information to apply.  A value of zero\n        indicates that this entry applies on all ports of the\n        device for which there is no other applicable entry.")
dot1qStaticUnicastAllowedToGoTo = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 1, 1, 3), PortList()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qStaticUnicastAllowedToGoTo.setDescription("The set of ports for which a frame with a specific\n        unicast address will be flooded in the event that it\n        has not been learned.  It also specifies the set of\n        ports on which a specific unicast address may be dynamically\n        learned.  The dot1qTpFdbTable will have an equivalent\n        entry with a dot1qTpFdbPort value of '0' until this\n        address has been learned, at which point it will be updated\n        with the port the address has been seen on.  This only\n        applies to ports that are members of the VLAN, defined\n        by dot1qVlanCurrentEgressPorts.  The default value of\n        this object is a string of ones of appropriate length.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.")
dot1qStaticUnicastStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("invalid", 2), ("permanent", 3), ("deleteOnReset", 4), ("deleteOnTimeout", 5),)).clone('permanent')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qStaticUnicastStatus.setDescription('This object indicates the status of this entry.\n            other(1) - this entry is currently in use, but\n                the conditions under which it will remain\n                so differ from the following values.\n            invalid(2) - writing this value to the object\n                removes the corresponding entry.\n            permanent(3) - this entry is currently in use\n                and will remain so after the next reset of\n                the bridge.\n            deleteOnReset(4) - this entry is currently in\n                use and will remain so until the next\n                reset of the bridge.\n            deleteOnTimeout(5) - this entry is currently in\n                use and will remain so until it is aged out.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qStaticMulticastTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 2), )
if mibBuilder.loadTexts: dot1qStaticMulticastTable.setDescription('A table containing filtering information for Multicast\n        and Broadcast MAC addresses for each VLAN, configured\n        into the device by (local or network) management\n        specifying the set of ports to which frames received\n        from specific ports and containing specific Multicast\n        and Broadcast destination addresses are allowed to be\n        forwarded.  A value of zero in this table (as the port\n        number from which frames with a specific destination\n        address are received) is used to specify all ports for\n        which there is no specific entry in this table for that\n        particular destination address.  Entries are valid for\n        Multicast and Broadcast addresses only.')
dot1qStaticMulticastEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 2, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qVlanIndex"), (0, "Q-BRIDGE-MIB", "dot1qStaticMulticastAddress"), (0, "Q-BRIDGE-MIB", "dot1qStaticMulticastReceivePort"))
if mibBuilder.loadTexts: dot1qStaticMulticastEntry.setDescription('Filtering information configured into the device by\n        (local or network) management specifying the set of\n        ports to which frames received from this specific port\n        for this VLAN and containing this Multicast or Broadcast\n        destination address are allowed to be forwarded.')
dot1qStaticMulticastAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 2, 1, 1), MacAddress())
if mibBuilder.loadTexts: dot1qStaticMulticastAddress.setDescription("The destination MAC address in a frame to which this\n        entry's filtering information applies.  This object must\n        take the value of a Multicast or Broadcast address.")
dot1qStaticMulticastReceivePort = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)))
if mibBuilder.loadTexts: dot1qStaticMulticastReceivePort.setDescription("Either the value '0' or the port number of the port\n        from which a frame must be received in order for this\n        entry's filtering information to apply.  A value of zero\n        indicates that this entry applies on all ports of the\n        device for which there is no other applicable entry.")
dot1qStaticMulticastStaticEgressPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 2, 1, 3), PortList()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qStaticMulticastStaticEgressPorts.setDescription('The set of ports to which frames received from a\n        specific port and destined for a specific Multicast or\n        Broadcast MAC address must be forwarded, regardless of\n        any dynamic information, e.g., from GMRP.  A port may not\n        be added in this set if it is already a member of the\n        set of ports in dot1qStaticMulticastForbiddenEgressPorts.\n        The default value of this object is a string of ones of\n        appropriate length.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qStaticMulticastForbiddenEgressPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 2, 1, 4), PortList()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qStaticMulticastForbiddenEgressPorts.setDescription('The set of ports to which frames received from a\n        specific port and destined for a specific Multicast or\n        Broadcast MAC address must not be forwarded, regardless\n        of any dynamic information, e.g., from GMRP.  A port may\n        not be added in this set if it is already a member of the\n        set of ports in dot1qStaticMulticastStaticEgressPorts.\n        The default value of this object is a string of zeros of\n        appropriate length.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qStaticMulticastStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 3, 2, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("invalid", 2), ("permanent", 3), ("deleteOnReset", 4), ("deleteOnTimeout", 5),)).clone('permanent')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qStaticMulticastStatus.setDescription('This object indicates the status of this entry.\n            other(1) - this entry is currently in use, but\n                the conditions under which it will remain\n                so differ from the following values.\n\n            invalid(2) - writing this value to the object\n                removes the corresponding entry.\n            permanent(3) - this entry is currently in use\n                and will remain so after the next reset of\n                the bridge.\n            deleteOnReset(4) - this entry is currently in\n                use and will remain so until the next\n                reset of the bridge.\n            deleteOnTimeout(5) - this entry is currently in\n                use and will remain so until it is aged out.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qVlanNumDeletes = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qVlanNumDeletes.setDescription('The number of times a VLAN entry has been deleted from\n        the dot1qVlanCurrentTable (for any reason).  If an entry\n        is deleted, then inserted, and then deleted, this\n        counter will be incremented by 2.')
dot1qVlanCurrentTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2), )
if mibBuilder.loadTexts: dot1qVlanCurrentTable.setDescription('A table containing current configuration information\n        for each VLAN currently configured into the device by\n        (local or network) management, or dynamically created\n        as a result of GVRP requests received.')
dot1qVlanCurrentEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qVlanTimeMark"), (0, "Q-BRIDGE-MIB", "dot1qVlanIndex"))
if mibBuilder.loadTexts: dot1qVlanCurrentEntry.setDescription('Information for a VLAN configured into the device by\n        (local or network) management, or dynamically created\n        as a result of GVRP requests received.')
dot1qVlanTimeMark = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2, 1, 1), TimeFilter())
if mibBuilder.loadTexts: dot1qVlanTimeMark.setDescription('A TimeFilter for this entry.  See the TimeFilter\n        textual convention to see how this works.')
dot1qVlanIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2, 1, 2), VlanIndex())
if mibBuilder.loadTexts: dot1qVlanIndex.setDescription('The VLAN-ID or other identifier referring to this VLAN.')
dot1qVlanFdbId = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qVlanFdbId.setDescription('The Filtering Database used by this VLAN.  This is one\n        of the dot1qFdbId values in the dot1qFdbTable.  This\n        value is allocated automatically by the device whenever\n        the VLAN is created: either dynamically by GVRP, or by\n        management, in dot1qVlanStaticTable.  Allocation of this\n        value follows the learning constraints defined for this\n        VLAN in dot1qLearningConstraintsTable.')
dot1qVlanCurrentEgressPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2, 1, 4), PortList()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qVlanCurrentEgressPorts.setDescription('The set of ports that are transmitting traffic for\n        this VLAN as either tagged or untagged frames.')
dot1qVlanCurrentUntaggedPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2, 1, 5), PortList()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qVlanCurrentUntaggedPorts.setDescription('The set of ports that are transmitting traffic for\n        this VLAN as untagged frames.')
dot1qVlanStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("other", 1), ("permanent", 2), ("dynamicGvrp", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qVlanStatus.setDescription('This object indicates the status of this entry.\n            other(1) - this entry is currently in use, but the\n                conditions under which it will remain so differ\n                from the following values.\n            permanent(2) - this entry, corresponding to an entry\n                in dot1qVlanStaticTable, is currently in use and\n                will remain so after the next reset of the\n                device.  The port lists for this entry include\n                ports from the equivalent dot1qVlanStaticTable\n                entry and ports learned dynamically.\n            dynamicGvrp(3) - this entry is currently in use\n                and will remain so until removed by GVRP.  There\n                is no static entry for this VLAN, and it will be\n                removed when the last port leaves the VLAN.')
dot1qVlanCreationTime = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 2, 1, 7), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qVlanCreationTime.setDescription('The value of sysUpTime when this VLAN was created.')
dot1qVlanStaticTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 3), )
if mibBuilder.loadTexts: dot1qVlanStaticTable.setDescription('A table containing static configuration information for\n        each VLAN configured into the device by (local or\n        network) management.  All entries are permanent and will\n        be restored after the device is reset.')
dot1qVlanStaticEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 3, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qVlanIndex"))
if mibBuilder.loadTexts: dot1qVlanStaticEntry.setDescription('Static information for a VLAN configured into the\n        device by (local or network) management.')
dot1qVlanStaticName = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 3, 1, 1), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,32))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1qVlanStaticName.setDescription('An administratively assigned string, which may be used\n        to identify the VLAN.')
dot1qVlanStaticEgressPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 3, 1, 2), PortList()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1qVlanStaticEgressPorts.setDescription('The set of ports that are permanently assigned to the\n        egress list for this VLAN by management.  Changes to a\n        bit in this object affect the per-port, per-VLAN\n        Registrar control for Registration Fixed for the\n        relevant GVRP state machine on each port.  A port may\n        not be added in this set if it is already a member of\n        the set of ports in dot1qVlanForbiddenEgressPorts.  The\n        default value of this object is a string of zeros of\n        appropriate length, indicating not fixed.')
dot1qVlanForbiddenEgressPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 3, 1, 3), PortList()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1qVlanForbiddenEgressPorts.setDescription('The set of ports that are prohibited by management\n        from being included in the egress list for this VLAN.\n        Changes to this object that cause a port to be included\n        or excluded affect the per-port, per-VLAN Registrar\n        control for Registration Forbidden for the relevant GVRP\n        state machine on each port.  A port may not be added in\n        this set if it is already a member of the set of ports\n        in dot1qVlanStaticEgressPorts.  The default value of\n        this object is a string of zeros of appropriate length,\n        excluding all ports from the forbidden set.')
dot1qVlanStaticUntaggedPorts = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 3, 1, 4), PortList()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1qVlanStaticUntaggedPorts.setDescription('The set of ports that should transmit egress packets\n        for this VLAN as untagged.  The default value of this\n        object for the default VLAN (dot1qVlanIndex = 1) is a string\n        of appropriate length including all ports.  There is no\n        specified default for other VLANs.  If a device agent cannot\n        support the set of ports being set, then it will reject the\n        set operation with an error.  For example, a\n        manager might attempt to set more than one VLAN to be untagged\n        on egress where the device does not support this IEEE 802.1Q\n        option.')
dot1qVlanStaticRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 3, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1qVlanStaticRowStatus.setDescription('This object indicates the status of this entry.')
dot1qNextFreeLocalVlanIndex = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(4096,2147483647),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qNextFreeLocalVlanIndex.setDescription('The next available value for dot1qVlanIndex of a local\n        VLAN entry in dot1qVlanStaticTable.  This will report\n        values >=4096 if a new Local VLAN may be created or else\n        the value 0 if this is not possible.\n\n        A row creation operation in this table for an entry with a local\n        VlanIndex value may fail if the current value of this object\n        is not used as the index.  Even if the value read is used,\n        there is no guarantee that it will still be the valid index\n        when the create operation is attempted; another manager may\n        have already got in during the intervening time interval.\n        In this case, dot1qNextFreeLocalVlanIndex should be re-read\n        and the creation re-tried with the new value.\n\n        This value will automatically change when the current value is\n        used to create a new row.')
dot1qPortVlanTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5), )
if mibBuilder.loadTexts: dot1qPortVlanTable.setDescription('A table containing per-port control and status\n        information for VLAN configuration in the device.')
dot1qPortVlanEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5, 1), )
dot1dBasePortEntry.registerAugmentions(("Q-BRIDGE-MIB", "dot1qPortVlanEntry"))
dot1qPortVlanEntry.setIndexNames(*dot1dBasePortEntry.getIndexNames())
if mibBuilder.loadTexts: dot1qPortVlanEntry.setDescription('Information controlling VLAN configuration for a port\n        on the device.  This is indexed by dot1dBasePort.')
dot1qPvid = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5, 1, 1), VlanIndex().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qPvid.setDescription('The PVID, the VLAN-ID assigned to untagged frames or\n        Priority-Tagged frames received on this port.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qPortAcceptableFrameTypes = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("admitAll", 1), ("admitOnlyVlanTagged", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qPortAcceptableFrameTypes.setDescription('When this is admitOnlyVlanTagged(2), the device will\n        discard untagged frames or Priority-Tagged frames\n        received on this port.  When admitAll(1), untagged\n        frames or Priority-Tagged frames received on this port\n        will be accepted and assigned to a VID based on the\n        PVID and VID Set for this port.\n\n        This control does not affect VLAN-independent Bridge\n        Protocol Data Unit (BPDU) frames, such as GVRP and\n        Spanning Tree Protocol (STP).  It does affect VLAN-\n        dependent BPDU frames, such as GMRP.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qPortIngressFiltering = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5, 1, 3), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qPortIngressFiltering.setDescription('When this is true(1), the device will discard incoming\n        frames for VLANs that do not include this Port in its\n        Member set.  When false(2), the port will accept all\n        incoming frames.\n\n        This control does not affect VLAN-independent BPDU\n        frames, such as GVRP and STP.  It does affect VLAN-\n        dependent BPDU frames, such as GMRP.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qPortGvrpStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5, 1, 4), EnabledStatus()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qPortGvrpStatus.setDescription('The state of GVRP operation on this port.  The value\n        enabled(1) indicates that GVRP is enabled on this port,\n        as long as dot1qGvrpStatus is also enabled for this\n        device.  When disabled(2) but dot1qGvrpStatus is still\n        enabled for the device, GVRP is disabled on this port:\n        any GVRP packets received will be silently discarded, and\n        no GVRP registrations will be propagated from other\n        ports.  This object affects all GVRP Applicant and\n        Registrar state machines on this port.  A transition\n        from disabled(2) to enabled(1) will cause a reset of all\n        GVRP state machines on this port.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qPortGvrpFailedRegistrations = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qPortGvrpFailedRegistrations.setDescription('The total number of failed GVRP registrations, for any\n        reason, on this port.')
dot1qPortGvrpLastPduOrigin = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5, 1, 6), MacAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qPortGvrpLastPduOrigin.setDescription('The Source MAC Address of the last GVRP message\n        received on this port.')
dot1qPortRestrictedVlanRegistration = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 5, 1, 7), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qPortRestrictedVlanRegistration.setDescription('The state of Restricted VLAN Registration on this port.\n         If the value of this control is true(1), then creation\n         of a new dynamic VLAN entry is permitted only if there\n         is a Static VLAN Registration Entry for the VLAN concerned,\n         in which the Registrar Administrative Control value for\n         this port is Normal Registration.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qPortVlanStatisticsTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 6), )
if mibBuilder.loadTexts: dot1qPortVlanStatisticsTable.setDescription('A table containing per-port, per-VLAN statistics for\n        traffic received.  Separate objects are provided for both the\n        most-significant and least-significant bits of statistics\n        counters for ports that are associated with this transparent\n        bridge.  The most-significant bit objects are only required on\n        high-capacity interfaces, as defined in the conformance clauses\n        for these objects.  This mechanism is provided as a way to read\n        64-bit counters for agents that support only SNMPv1.\n\n        Note that the reporting of most-significant and least-\n        significant counter bits separately runs the risk of missing\n        an overflow of the lower bits in the interval between sampling.\n        The manager must be aware of this possibility, even within the\n        same varbindlist, when interpreting the results of a request or\n        asynchronous notification.')
dot1qPortVlanStatisticsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 6, 1), ).setIndexNames((0, "BRIDGE-MIB", "dot1dBasePort"), (0, "Q-BRIDGE-MIB", "dot1qVlanIndex"))
if mibBuilder.loadTexts: dot1qPortVlanStatisticsEntry.setDescription('Traffic statistics for a VLAN on an interface.')
dot1qTpVlanPortInFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 6, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortInFrames.setDescription('The number of valid frames received by this port from\n        its segment that were classified as belonging to this\n        VLAN.  Note that a frame received on this port is\n        counted by this object if and only if it is for a\n        protocol being processed by the local forwarding process\n        for this VLAN.  This object includes received bridge\n        management frames classified as belonging to this VLAN\n        (e.g., GMRP, but not GVRP or STP.')
dot1qTpVlanPortOutFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 6, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortOutFrames.setDescription('The number of valid frames transmitted by this port to\n        its segment from the local forwarding process for this\n        VLAN.  This includes bridge management frames originated\n        by this device that are classified as belonging to this\n        VLAN (e.g., GMRP, but not GVRP or STP).')
dot1qTpVlanPortInDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 6, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortInDiscards.setDescription('The number of valid frames received by this port from\n        its segment that were classified as belonging to this\n        VLAN and that were discarded due to VLAN-related reasons.\n        Specifically, the IEEE 802.1Q counters for Discard\n        Inbound and Discard on Ingress Filtering.')
dot1qTpVlanPortInOverflowFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 6, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortInOverflowFrames.setDescription('The number of times the associated\n        dot1qTpVlanPortInFrames counter has overflowed.')
dot1qTpVlanPortOutOverflowFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 6, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortOutOverflowFrames.setDescription('The number of times the associated\n        dot1qTpVlanPortOutFrames counter has overflowed.')
dot1qTpVlanPortInOverflowDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 6, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortInOverflowDiscards.setDescription('The number of times the associated\n        dot1qTpVlanPortInDiscards counter has overflowed.')
dot1qPortVlanHCStatisticsTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 7), )
if mibBuilder.loadTexts: dot1qPortVlanHCStatisticsTable.setDescription('A table containing per-port, per-VLAN statistics for\n        traffic on high-capacity interfaces.')
dot1qPortVlanHCStatisticsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 7, 1), ).setIndexNames((0, "BRIDGE-MIB", "dot1dBasePort"), (0, "Q-BRIDGE-MIB", "dot1qVlanIndex"))
if mibBuilder.loadTexts: dot1qPortVlanHCStatisticsEntry.setDescription('Traffic statistics for a VLAN on a high-capacity\n        interface.')
dot1qTpVlanPortHCInFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 7, 1, 1), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortHCInFrames.setDescription('The number of valid frames received by this port from\n        its segment that were classified as belonging to this\n        VLAN.  Note that a frame received on this port is\n        counted by this object if and only if it is for a\n        protocol being processed by the local forwarding process\n        for this VLAN.  This object includes received bridge\n        management frames classified as belonging to this VLAN\n        (e.g., GMRP, but not GVRP or STP).')
dot1qTpVlanPortHCOutFrames = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 7, 1, 2), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortHCOutFrames.setDescription('The number of valid frames transmitted by this port to\n        its segment from the local forwarding process for this\n        VLAN.  This includes bridge management frames originated\n        by this device that are classified as belonging to this\n        VLAN (e.g., GMRP, but not GVRP or STP).')
dot1qTpVlanPortHCInDiscards = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 7, 1, 3), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dot1qTpVlanPortHCInDiscards.setDescription('The number of valid frames received by this port from\n        its segment that were classified as belonging to this\n        VLAN and that were discarded due to VLAN-related reasons.\n        Specifically, the IEEE 802.1Q counters for Discard\n        Inbound and Discard on Ingress Filtering.')
dot1qLearningConstraintsTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 8), )
if mibBuilder.loadTexts: dot1qLearningConstraintsTable.setDescription('A table containing learning constraints for sets of\n        Shared and Independent VLANs.')
dot1qLearningConstraintsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 8, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1qConstraintVlan"), (0, "Q-BRIDGE-MIB", "dot1qConstraintSet"))
if mibBuilder.loadTexts: dot1qLearningConstraintsEntry.setDescription('A learning constraint defined for a VLAN.')
dot1qConstraintVlan = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 8, 1, 1), VlanIndex())
if mibBuilder.loadTexts: dot1qConstraintVlan.setDescription('The index of the row in dot1qVlanCurrentTable for the\n        VLAN constrained by this entry.')
dot1qConstraintSet = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 8, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)))
if mibBuilder.loadTexts: dot1qConstraintSet.setDescription('The identity of the constraint set to which\n        dot1qConstraintVlan belongs.  These values may be chosen\n        by the management station.')
dot1qConstraintType = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 8, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("independent", 1), ("shared", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1qConstraintType.setDescription('The type of constraint this entry defines.\n            independent(1) - the VLAN, dot1qConstraintVlan,\n                uses a filtering database independent from all\n                other VLANs in the same set, defined by\n                dot1qConstraintSet.\n            shared(2) - the VLAN, dot1qConstraintVlan, shares\n                the same filtering database as all other VLANs\n                in the same set, defined by dot1qConstraintSet.')
dot1qConstraintStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 8, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1qConstraintStatus.setDescription('The status of this entry.')
dot1qConstraintSetDefault = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qConstraintSetDefault.setDescription('The identity of the constraint set to which a VLAN\n        belongs, if there is not an explicit entry for that VLAN\n        in dot1qLearningConstraintsTable.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1qConstraintTypeDefault = MibScalar((1, 3, 6, 1, 2, 1, 17, 7, 1, 4, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("independent", 1), ("shared", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dot1qConstraintTypeDefault.setDescription('The type of constraint set to which a VLAN belongs, if\n        there is not an explicit entry for that VLAN in\n        dot1qLearningConstraintsTable.  The types are as defined\n        for dot1qConstraintType.\n\n        The value of this object MUST be retained across\n        reinitializations of the management system.')
dot1vProtocolGroupTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 1), )
if mibBuilder.loadTexts: dot1vProtocolGroupTable.setDescription('A table that contains mappings from Protocol\n         Templates to Protocol Group Identifiers used for\n         Port-and-Protocol-based VLAN Classification.')
dot1vProtocolGroupEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 1, 1), ).setIndexNames((0, "Q-BRIDGE-MIB", "dot1vProtocolTemplateFrameType"), (0, "Q-BRIDGE-MIB", "dot1vProtocolTemplateProtocolValue"))
if mibBuilder.loadTexts: dot1vProtocolGroupEntry.setDescription('A mapping from a Protocol Template to a Protocol\n         Group Identifier.')
dot1vProtocolTemplateFrameType = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("ethernet", 1), ("rfc1042", 2), ("snap8021H", 3), ("snapOther", 4), ("llcOther", 5),)))
if mibBuilder.loadTexts: dot1vProtocolTemplateFrameType.setDescription("The data-link encapsulation format or the\n         'detagged_frame_type' in a Protocol Template.")
dot1vProtocolTemplateProtocolValue = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 1, 1, 2), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(2,2),ValueSizeConstraint(5,5),)))
if mibBuilder.loadTexts: dot1vProtocolTemplateProtocolValue.setDescription("The identification of the protocol above the data-link\n         layer in a Protocol Template.  Depending on the\n         frame type, the octet string will have one of the\n         following values:\n\n         For 'ethernet', 'rfc1042' and 'snap8021H',\n             this is the 16-bit (2-octet) IEEE 802.3 Type Field.\n         For 'snapOther',\n             this is the 40-bit (5-octet) PID.\n         For 'llcOther',\n             this is the 2-octet IEEE 802.2 Link Service Access\n             Point (LSAP) pair: first octet for Destination Service\n             Access Point (DSAP) and second octet for Source Service\n             Access Point (SSAP).")
dot1vProtocolGroupId = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1vProtocolGroupId.setDescription('Represents a group of protocols that are associated\n         together when assigning a VID to a frame.')
dot1vProtocolGroupRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 1, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1vProtocolGroupRowStatus.setDescription('This object indicates the status of this entry.')
dot1vProtocolPortTable = MibTable((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 2), )
if mibBuilder.loadTexts: dot1vProtocolPortTable.setDescription('A table that contains VID sets used for\n         Port-and-Protocol-based VLAN Classification.')
dot1vProtocolPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 2, 1), ).setIndexNames((0, "BRIDGE-MIB", "dot1dBasePort"), (0, "Q-BRIDGE-MIB", "dot1vProtocolPortGroupId"))
if mibBuilder.loadTexts: dot1vProtocolPortEntry.setDescription('A VID set for a port.')
dot1vProtocolPortGroupId = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: dot1vProtocolPortGroupId.setDescription('Designates a group of protocols in the Protocol\n         Group Database.')
dot1vProtocolPortGroupVid = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,4094))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1vProtocolPortGroupVid.setDescription('The VID associated with a group of protocols for\n         each port.')
dot1vProtocolPortRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 17, 7, 1, 5, 2, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dot1vProtocolPortRowStatus.setDescription('This object indicates the status of this entry.')
qBridgeConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 2))
qBridgeGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 2, 1))
qBridgeCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 17, 7, 2, 2))
qBridgeBaseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 1)).setObjects(*(("Q-BRIDGE-MIB", "dot1qVlanVersionNumber"), ("Q-BRIDGE-MIB", "dot1qMaxVlanId"), ("Q-BRIDGE-MIB", "dot1qMaxSupportedVlans"), ("Q-BRIDGE-MIB", "dot1qNumVlans"), ("Q-BRIDGE-MIB", "dot1qGvrpStatus"),))
if mibBuilder.loadTexts: qBridgeBaseGroup.setDescription('A collection of objects providing device-level control\n        and status information for the Virtual LAN bridge\n        services.')
qBridgeFdbUnicastGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 2)).setObjects(*(("Q-BRIDGE-MIB", "dot1qFdbDynamicCount"), ("Q-BRIDGE-MIB", "dot1qTpFdbPort"), ("Q-BRIDGE-MIB", "dot1qTpFdbStatus"),))
if mibBuilder.loadTexts: qBridgeFdbUnicastGroup.setDescription('A collection of objects providing information about all\n        unicast addresses, learned dynamically or statically\n        configured by management, in each Filtering Database.')
qBridgeFdbMulticastGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 3)).setObjects(*(("Q-BRIDGE-MIB", "dot1qTpGroupEgressPorts"), ("Q-BRIDGE-MIB", "dot1qTpGroupLearnt"),))
if mibBuilder.loadTexts: qBridgeFdbMulticastGroup.setDescription('A collection of objects providing information about all\n        multicast addresses, learned dynamically or statically\n        configured by management, in each Filtering Database.')
qBridgeServiceRequirementsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 4)).setObjects(*(("Q-BRIDGE-MIB", "dot1qForwardAllPorts"), ("Q-BRIDGE-MIB", "dot1qForwardAllStaticPorts"), ("Q-BRIDGE-MIB", "dot1qForwardAllForbiddenPorts"), ("Q-BRIDGE-MIB", "dot1qForwardUnregisteredPorts"), ("Q-BRIDGE-MIB", "dot1qForwardUnregisteredStaticPorts"), ("Q-BRIDGE-MIB", "dot1qForwardUnregisteredForbiddenPorts"),))
if mibBuilder.loadTexts: qBridgeServiceRequirementsGroup.setDescription('A collection of objects providing information about\n        service requirements, learned dynamically or statically\n        configured by management, in each Filtering Database.')
qBridgeFdbStaticGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 5)).setObjects(*(("Q-BRIDGE-MIB", "dot1qStaticUnicastAllowedToGoTo"), ("Q-BRIDGE-MIB", "dot1qStaticUnicastStatus"), ("Q-BRIDGE-MIB", "dot1qStaticMulticastStaticEgressPorts"), ("Q-BRIDGE-MIB", "dot1qStaticMulticastForbiddenEgressPorts"), ("Q-BRIDGE-MIB", "dot1qStaticMulticastStatus"),))
if mibBuilder.loadTexts: qBridgeFdbStaticGroup.setDescription('A collection of objects providing information about\n        unicast and multicast addresses statically configured by\n        management, in each Filtering Database or VLAN.')
qBridgeVlanGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 6)).setObjects(*(("Q-BRIDGE-MIB", "dot1qVlanNumDeletes"), ("Q-BRIDGE-MIB", "dot1qVlanFdbId"), ("Q-BRIDGE-MIB", "dot1qVlanCurrentEgressPorts"), ("Q-BRIDGE-MIB", "dot1qVlanCurrentUntaggedPorts"), ("Q-BRIDGE-MIB", "dot1qVlanStatus"), ("Q-BRIDGE-MIB", "dot1qVlanCreationTime"),))
if mibBuilder.loadTexts: qBridgeVlanGroup.setDescription('A collection of objects providing information about\n        all VLANs currently configured on this device.')
qBridgeVlanStaticGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 7)).setObjects(*(("Q-BRIDGE-MIB", "dot1qVlanStaticName"), ("Q-BRIDGE-MIB", "dot1qVlanStaticEgressPorts"), ("Q-BRIDGE-MIB", "dot1qVlanForbiddenEgressPorts"), ("Q-BRIDGE-MIB", "dot1qVlanStaticUntaggedPorts"), ("Q-BRIDGE-MIB", "dot1qVlanStaticRowStatus"), ("Q-BRIDGE-MIB", "dot1qNextFreeLocalVlanIndex"),))
if mibBuilder.loadTexts: qBridgeVlanStaticGroup.setDescription('A collection of objects providing information about\n        VLANs statically configured by management.')
qBridgePortGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 8)).setObjects(*(("Q-BRIDGE-MIB", "dot1qPvid"), ("Q-BRIDGE-MIB", "dot1qPortAcceptableFrameTypes"), ("Q-BRIDGE-MIB", "dot1qPortIngressFiltering"), ("Q-BRIDGE-MIB", "dot1qPortGvrpStatus"), ("Q-BRIDGE-MIB", "dot1qPortGvrpFailedRegistrations"), ("Q-BRIDGE-MIB", "dot1qPortGvrpLastPduOrigin"),))
if mibBuilder.loadTexts: qBridgePortGroup.setDescription('A collection of objects providing port-level VLAN\n        control and status information for all ports.')
qBridgeVlanStatisticsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 9)).setObjects(*(("Q-BRIDGE-MIB", "dot1qTpVlanPortInFrames"), ("Q-BRIDGE-MIB", "dot1qTpVlanPortOutFrames"), ("Q-BRIDGE-MIB", "dot1qTpVlanPortInDiscards"),))
if mibBuilder.loadTexts: qBridgeVlanStatisticsGroup.setDescription('A collection of objects providing per-port packet\n        statistics for all VLANs currently configured on this\n        device.')
qBridgeVlanStatisticsOverflowGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 10)).setObjects(*(("Q-BRIDGE-MIB", "dot1qTpVlanPortInOverflowFrames"), ("Q-BRIDGE-MIB", "dot1qTpVlanPortOutOverflowFrames"), ("Q-BRIDGE-MIB", "dot1qTpVlanPortInOverflowDiscards"),))
if mibBuilder.loadTexts: qBridgeVlanStatisticsOverflowGroup.setDescription('A collection of objects providing overflow counters for\n        per-port packet statistics for all VLANs currently configured\n        on this device for high-capacity interfaces, defined as those\n        that have the value of the corresponding instance of\n        ifSpeed greater than 650,000,000 bits/second.')
qBridgeVlanHCStatisticsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 11)).setObjects(*(("Q-BRIDGE-MIB", "dot1qTpVlanPortHCInFrames"), ("Q-BRIDGE-MIB", "dot1qTpVlanPortHCOutFrames"), ("Q-BRIDGE-MIB", "dot1qTpVlanPortHCInDiscards"),))
if mibBuilder.loadTexts: qBridgeVlanHCStatisticsGroup.setDescription('A collection of objects providing per-port packet\n        statistics for all VLANs currently configured on this\n        device for high-capacity interfaces, defined as those\n        that have the value of the corresponding instance of\n        ifSpeed greater than 650,000,000 bits/second.')
qBridgeLearningConstraintsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 12)).setObjects(*(("Q-BRIDGE-MIB", "dot1qConstraintType"), ("Q-BRIDGE-MIB", "dot1qConstraintStatus"),))
if mibBuilder.loadTexts: qBridgeLearningConstraintsGroup.setDescription('A collection of objects defining the Filtering Database\n        constraints all VLANs have with each other.')
qBridgeLearningConstraintDefaultGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 13)).setObjects(*(("Q-BRIDGE-MIB", "dot1qConstraintSetDefault"), ("Q-BRIDGE-MIB", "dot1qConstraintTypeDefault"),))
if mibBuilder.loadTexts: qBridgeLearningConstraintDefaultGroup.setDescription('A collection of objects defining the default Filtering\n        Database constraints for VLANs that have no specific\n        constraints defined.')
qBridgeClassificationDeviceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 14)).setObjects(*(("Q-BRIDGE-MIB", "dot1vProtocolGroupId"), ("Q-BRIDGE-MIB", "dot1vProtocolGroupRowStatus"),))
if mibBuilder.loadTexts: qBridgeClassificationDeviceGroup.setDescription('VLAN classification information for the bridge.')
qBridgeClassificationPortGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 15)).setObjects(*(("Q-BRIDGE-MIB", "dot1vProtocolPortGroupVid"), ("Q-BRIDGE-MIB", "dot1vProtocolPortRowStatus"),))
if mibBuilder.loadTexts: qBridgeClassificationPortGroup.setDescription('VLAN classification information for individual ports.')
qBridgePortGroup2 = ObjectGroup((1, 3, 6, 1, 2, 1, 17, 7, 2, 1, 16)).setObjects(*(("Q-BRIDGE-MIB", "dot1qPvid"), ("Q-BRIDGE-MIB", "dot1qPortAcceptableFrameTypes"), ("Q-BRIDGE-MIB", "dot1qPortIngressFiltering"), ("Q-BRIDGE-MIB", "dot1qPortGvrpStatus"), ("Q-BRIDGE-MIB", "dot1qPortGvrpFailedRegistrations"), ("Q-BRIDGE-MIB", "dot1qPortGvrpLastPduOrigin"), ("Q-BRIDGE-MIB", "dot1qPortRestrictedVlanRegistration"),))
if mibBuilder.loadTexts: qBridgePortGroup2.setDescription('A collection of objects providing port-level VLAN\n        control and status information for all ports.')
qBridgeCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 17, 7, 2, 2, 1)).setObjects(*(("Q-BRIDGE-MIB", "qBridgeBaseGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanStaticGroup"), ("Q-BRIDGE-MIB", "qBridgePortGroup"), ("Q-BRIDGE-MIB", "qBridgeFdbUnicastGroup"), ("Q-BRIDGE-MIB", "qBridgeFdbMulticastGroup"), ("Q-BRIDGE-MIB", "qBridgeServiceRequirementsGroup"), ("Q-BRIDGE-MIB", "qBridgeFdbStaticGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanStatisticsGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanStatisticsOverflowGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanHCStatisticsGroup"), ("Q-BRIDGE-MIB", "qBridgeLearningConstraintsGroup"), ("Q-BRIDGE-MIB", "qBridgeLearningConstraintDefaultGroup"),))
if mibBuilder.loadTexts: qBridgeCompliance.setDescription('The compliance statement for device support of Virtual\n        LAN Bridge services.\n\n        RFC2674 was silent about the expected persistence of the\n        read-write objects in this MIB module.  Applications MUST\n        NOT assume that the values of the read-write objects are\n        persistent across reinitializations of the management\n        system and MUST NOT assume that the values are not\n        persistent across reinitializations of the management\n        system.')
qBridgeCompliance2 = ModuleCompliance((1, 3, 6, 1, 2, 1, 17, 7, 2, 2, 2)).setObjects(*(("Q-BRIDGE-MIB", "qBridgeBaseGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanStaticGroup"), ("Q-BRIDGE-MIB", "qBridgePortGroup2"), ("Q-BRIDGE-MIB", "qBridgeFdbUnicastGroup"), ("Q-BRIDGE-MIB", "qBridgeFdbMulticastGroup"), ("Q-BRIDGE-MIB", "qBridgeServiceRequirementsGroup"), ("Q-BRIDGE-MIB", "qBridgeFdbStaticGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanStatisticsGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanStatisticsOverflowGroup"), ("Q-BRIDGE-MIB", "qBridgeVlanHCStatisticsGroup"), ("Q-BRIDGE-MIB", "qBridgeLearningConstraintsGroup"), ("Q-BRIDGE-MIB", "qBridgeLearningConstraintDefaultGroup"), ("Q-BRIDGE-MIB", "qBridgeClassificationDeviceGroup"), ("Q-BRIDGE-MIB", "qBridgeClassificationPortGroup"),))
if mibBuilder.loadTexts: qBridgeCompliance2.setDescription('The compliance statement for device support of Virtual\n        LAN Bridge services.\n\n        This document clarifies the persistence requirements for\n        the read-write objects in this MIB module.  All\n        implementations claiming compliance to qBridgeCompliance2\n        MUST retain the values of those read-write objects that\n        specify this requirement.')
mibBuilder.exportSymbols("Q-BRIDGE-MIB", dot1qStaticMulticastStatus=dot1qStaticMulticastStatus, dot1qPortGvrpStatus=dot1qPortGvrpStatus, dot1vProtocolTemplateProtocolValue=dot1vProtocolTemplateProtocolValue, dot1qTpGroupTable=dot1qTpGroupTable, dot1qTpGroupEgressPorts=dot1qTpGroupEgressPorts, qBridgeVlanStaticGroup=qBridgeVlanStaticGroup, dot1qVlanFdbId=dot1qVlanFdbId, dot1qVlanStaticTable=dot1qVlanStaticTable, dot1vProtocolGroupTable=dot1vProtocolGroupTable, dot1qStatic=dot1qStatic, dot1vProtocolGroupEntry=dot1vProtocolGroupEntry, dot1qTpFdbStatus=dot1qTpFdbStatus, dot1qPortVlanEntry=dot1qPortVlanEntry, qBridgeFdbMulticastGroup=qBridgeFdbMulticastGroup, dot1qVlanNumDeletes=dot1qVlanNumDeletes, dot1qTpVlanPortHCInDiscards=dot1qTpVlanPortHCInDiscards, dot1vProtocol=dot1vProtocol, dot1qTpVlanPortInOverflowDiscards=dot1qTpVlanPortInOverflowDiscards, dot1qConstraintTypeDefault=dot1qConstraintTypeDefault, dot1qTpVlanPortInOverflowFrames=dot1qTpVlanPortInOverflowFrames, dot1qStaticUnicastAddress=dot1qStaticUnicastAddress, dot1qPortIngressFiltering=dot1qPortIngressFiltering, qBridgeLearningConstraintsGroup=qBridgeLearningConstraintsGroup, dot1qForwardUnregisteredTable=dot1qForwardUnregisteredTable, dot1qVlanTimeMark=dot1qVlanTimeMark, dot1qTpFdbPort=dot1qTpFdbPort, dot1qTpVlanPortInFrames=dot1qTpVlanPortInFrames, VlanIndex=VlanIndex, VlanIdOrNone=VlanIdOrNone, dot1vProtocolPortEntry=dot1vProtocolPortEntry, qBridgeGroups=qBridgeGroups, qBridgeClassificationDeviceGroup=qBridgeClassificationDeviceGroup, dot1qStaticMulticastEntry=dot1qStaticMulticastEntry, dot1qPortVlanHCStatisticsTable=dot1qPortVlanHCStatisticsTable, qBridgeMIBObjects=qBridgeMIBObjects, dot1qStaticMulticastTable=dot1qStaticMulticastTable, dot1qPvid=dot1qPvid, dot1qTpFdbEntry=dot1qTpFdbEntry, qBridgeConformance=qBridgeConformance, dot1qConstraintVlan=dot1qConstraintVlan, dot1qTpFdbAddress=dot1qTpFdbAddress, dot1qStaticUnicastAllowedToGoTo=dot1qStaticUnicastAllowedToGoTo, qBridgeCompliances=qBridgeCompliances, dot1vProtocolPortRowStatus=dot1vProtocolPortRowStatus, dot1qForwardUnregisteredEntry=dot1qForwardUnregisteredEntry, dot1qTp=dot1qTp, qBridgeFdbStaticGroup=qBridgeFdbStaticGroup, dot1qPortAcceptableFrameTypes=dot1qPortAcceptableFrameTypes, qBridgeLearningConstraintDefaultGroup=qBridgeLearningConstraintDefaultGroup, dot1qVlanForbiddenEgressPorts=dot1qVlanForbiddenEgressPorts, dot1vProtocolGroupRowStatus=dot1vProtocolGroupRowStatus, dot1qStaticUnicastTable=dot1qStaticUnicastTable, dot1qVlanStatus=dot1qVlanStatus, dot1qTpVlanPortHCInFrames=dot1qTpVlanPortHCInFrames, dot1qTpVlanPortInDiscards=dot1qTpVlanPortInDiscards, dot1qPortVlanTable=dot1qPortVlanTable, dot1qPortVlanHCStatisticsEntry=dot1qPortVlanHCStatisticsEntry, dot1qStaticUnicastStatus=dot1qStaticUnicastStatus, dot1qStaticMulticastAddress=dot1qStaticMulticastAddress, dot1qNumVlans=dot1qNumVlans, dot1qPortRestrictedVlanRegistration=dot1qPortRestrictedVlanRegistration, dot1qVlanCurrentUntaggedPorts=dot1qVlanCurrentUntaggedPorts, dot1qForwardUnregisteredPorts=dot1qForwardUnregisteredPorts, dot1qVlanStaticEgressPorts=dot1qVlanStaticEgressPorts, dot1qFdbTable=dot1qFdbTable, dot1qTpGroupEntry=dot1qTpGroupEntry, dot1qLearningConstraintsTable=dot1qLearningConstraintsTable, dot1qVlanVersionNumber=dot1qVlanVersionNumber, dot1qConstraintSetDefault=dot1qConstraintSetDefault, dot1qMaxSupportedVlans=dot1qMaxSupportedVlans, qBridgeClassificationPortGroup=qBridgeClassificationPortGroup, dot1vProtocolPortGroupVid=dot1vProtocolPortGroupVid, dot1qVlanCreationTime=dot1qVlanCreationTime, qBridgeFdbUnicastGroup=qBridgeFdbUnicastGroup, dot1qTpGroupLearnt=dot1qTpGroupLearnt, dot1qVlanIndex=dot1qVlanIndex, qBridgeMIB=qBridgeMIB, dot1vProtocolTemplateFrameType=dot1vProtocolTemplateFrameType, dot1qPortGvrpLastPduOrigin=dot1qPortGvrpLastPduOrigin, dot1qTpVlanPortHCOutFrames=dot1qTpVlanPortHCOutFrames, dot1qTpFdbTable=dot1qTpFdbTable, dot1qPortVlanStatisticsEntry=dot1qPortVlanStatisticsEntry, dot1qStaticMulticastForbiddenEgressPorts=dot1qStaticMulticastForbiddenEgressPorts, dot1qPortGvrpFailedRegistrations=dot1qPortGvrpFailedRegistrations, dot1vProtocolGroupId=dot1vProtocolGroupId, dot1qForwardAllStaticPorts=dot1qForwardAllStaticPorts, dot1qFdbId=dot1qFdbId, qBridgeVlanStatisticsOverflowGroup=qBridgeVlanStatisticsOverflowGroup, dot1qVlanStaticUntaggedPorts=dot1qVlanStaticUntaggedPorts, dot1qTpGroupAddress=dot1qTpGroupAddress, dot1qTpVlanPortOutFrames=dot1qTpVlanPortOutFrames, dot1qPortVlanStatisticsTable=dot1qPortVlanStatisticsTable, dot1qStaticUnicastEntry=dot1qStaticUnicastEntry, PYSNMP_MODULE_ID=qBridgeMIB, dot1qStaticMulticastStaticEgressPorts=dot1qStaticMulticastStaticEgressPorts, VlanIdOrAny=VlanIdOrAny, dot1vProtocolPortTable=dot1vProtocolPortTable, qBridgeBaseGroup=qBridgeBaseGroup, qBridgeCompliance2=qBridgeCompliance2, qBridgeVlanHCStatisticsGroup=qBridgeVlanHCStatisticsGroup, dot1qFdbEntry=dot1qFdbEntry, dot1qForwardUnregisteredForbiddenPorts=dot1qForwardUnregisteredForbiddenPorts, dot1qMaxVlanId=dot1qMaxVlanId, dot1qForwardAllPorts=dot1qForwardAllPorts, dot1qTpVlanPortOutOverflowFrames=dot1qTpVlanPortOutOverflowFrames, dot1qVlanStaticRowStatus=dot1qVlanStaticRowStatus, PortList=PortList, qBridgePortGroup=qBridgePortGroup, qBridgeServiceRequirementsGroup=qBridgeServiceRequirementsGroup, dot1qForwardAllEntry=dot1qForwardAllEntry, VlanId=VlanId, dot1qStaticUnicastReceivePort=dot1qStaticUnicastReceivePort, dot1vProtocolPortGroupId=dot1vProtocolPortGroupId, dot1qVlanCurrentTable=dot1qVlanCurrentTable, dot1qLearningConstraintsEntry=dot1qLearningConstraintsEntry, dot1qGvrpStatus=dot1qGvrpStatus, VlanIdOrAnyOrNone=VlanIdOrAnyOrNone, dot1qVlanCurrentEgressPorts=dot1qVlanCurrentEgressPorts, qBridgeVlanStatisticsGroup=qBridgeVlanStatisticsGroup, qBridgeCompliance=qBridgeCompliance, dot1qFdbDynamicCount=dot1qFdbDynamicCount, dot1qVlanCurrentEntry=dot1qVlanCurrentEntry, dot1qVlanStaticEntry=dot1qVlanStaticEntry, dot1qNextFreeLocalVlanIndex=dot1qNextFreeLocalVlanIndex, dot1qForwardAllForbiddenPorts=dot1qForwardAllForbiddenPorts, dot1qConstraintSet=dot1qConstraintSet, dot1qForwardAllTable=dot1qForwardAllTable, dot1qConstraintType=dot1qConstraintType, qBridgePortGroup2=qBridgePortGroup2, dot1qForwardUnregisteredStaticPorts=dot1qForwardUnregisteredStaticPorts, dot1qVlan=dot1qVlan, dot1qStaticMulticastReceivePort=dot1qStaticMulticastReceivePort, dot1qConstraintStatus=dot1qConstraintStatus, dot1qVlanStaticName=dot1qVlanStaticName, qBridgeVlanGroup=qBridgeVlanGroup, dot1qBase=dot1qBase)



#
# PySNMP MIB module HOST-RESOURCES-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/HOST-RESOURCES-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:12:48 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsIntersection")
( InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( Bits, ModuleIdentity, Counter32, IpAddress, Unsigned32, MibIdentifier, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, mib_2, NotificationType, Counter64, TimeTicks, Gauge32, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "ModuleIdentity", "Counter32", "IpAddress", "Unsigned32", "MibIdentifier", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "mib-2", "NotificationType", "Counter64", "TimeTicks", "Gauge32", "Integer32")
( TruthValue, AutonomousType, TextualConvention, DisplayString, DateAndTime, ) = mibBuilder.importSymbols("SNMPv2-TC", "TruthValue", "AutonomousType", "TextualConvention", "DisplayString", "DateAndTime")
hostResourcesMibModule = ModuleIdentity((1, 3, 6, 1, 2, 1, 25, 7, 1)).setRevisions(("2000-03-06 00:00", "1999-10-20 22:00",))
if mibBuilder.loadTexts: hostResourcesMibModule.setLastUpdated('200003060000Z')
if mibBuilder.loadTexts: hostResourcesMibModule.setOrganization('IETF Host Resources MIB Working Group')
if mibBuilder.loadTexts: hostResourcesMibModule.setContactInfo('Steve Waldbusser\n          Postal: Lucent Technologies, Inc.\n                  1213 Innsbruck Dr.\n                  Sunnyvale, CA 94089\n                  USA\n          Phone:  650-318-1251\n          Fax:    650-318-1633\n          Email:  waldbusser@lucent.com\n\n\n          In addition, the Host Resources MIB mailing list is\n          dedicated to discussion of this MIB. To join the\n          mailing list, send a request message to\n          hostmib-request@andrew.cmu.edu. The mailing list\n          address is hostmib@andrew.cmu.edu.')
if mibBuilder.loadTexts: hostResourcesMibModule.setDescription("This MIB is for use in managing host systems. The term\n          `host' is construed to mean any computer that communicates\n          with other similar computers attached to the internet and\n          that is directly used by one or more human beings. Although\n          this MIB does not necessarily apply to devices whose primary\n          function is communications services (e.g., terminal servers,\n          routers, bridges, monitoring equipment), such relevance is\n          not explicitly precluded.  This MIB instruments attributes\n          common to all internet hosts including, for example, both\n          personal computers and systems that run variants of Unix.")
host = MibIdentifier((1, 3, 6, 1, 2, 1, 25))
hrSystem = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 1))
hrStorage = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 2))
hrDevice = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 3))
hrSWRun = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 4))
hrSWRunPerf = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 5))
hrSWInstalled = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 6))
hrMIBAdminInfo = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 7))
class KBytes(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class ProductID(ObjectIdentifier, TextualConvention):
    pass

class InternationalDisplayString(OctetString, TextualConvention):
    pass

hrSystemUptime = MibScalar((1, 3, 6, 1, 2, 1, 25, 1, 1), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSystemUptime.setDescription('The amount of time since this host was last\n           initialized.  Note that this is different from\n           sysUpTime in the SNMPv2-MIB [RFC1907] because\n           sysUpTime is the uptime of the network management\n           portion of the system.')
hrSystemDate = MibScalar((1, 3, 6, 1, 2, 1, 25, 1, 2), DateAndTime()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hrSystemDate.setDescription("The host's notion of the local date and time of day.")
hrSystemInitialLoadDevice = MibScalar((1, 3, 6, 1, 2, 1, 25, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hrSystemInitialLoadDevice.setDescription('The index of the hrDeviceEntry for the device from\n           which this host is configured to load its initial\n           operating system configuration (i.e., which operating\n           system code and/or boot parameters).\n\n           Note that writing to this object just changes the\n           configuration that will be used the next time the\n           operating system is loaded and does not actually cause\n           the reload to occur.')
hrSystemInitialLoadParameters = MibScalar((1, 3, 6, 1, 2, 1, 25, 1, 4), InternationalDisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hrSystemInitialLoadParameters.setDescription('This object contains the parameters (e.g. a pathname\n           and parameter) supplied to the load device when\n           requesting the initial operating system configuration\n           from that device.\n\n        Note that writing to this object just changes the\n        configuration that will be used the next time the\n        operating system is loaded and does not actually cause\n        the reload to occur.')
hrSystemNumUsers = MibScalar((1, 3, 6, 1, 2, 1, 25, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSystemNumUsers.setDescription('The number of user sessions for which this host is\n           storing state information.  A session is a collection\n           of processes requiring a single act of user\n           authentication and possibly subject to collective job\n           control.')
hrSystemProcesses = MibScalar((1, 3, 6, 1, 2, 1, 25, 1, 6), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSystemProcesses.setDescription('The number of process contexts currently loaded or\n           running on this system.')
hrSystemMaxProcesses = MibScalar((1, 3, 6, 1, 2, 1, 25, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSystemMaxProcesses.setDescription('The maximum number of process contexts this system\n           can support.  If there is no fixed maximum, the value\n           should be zero.  On systems that have a fixed maximum,\n           this object can help diagnose failures that occur when\n           this maximum is reached.')
hrStorageTypes = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 2, 1))
hrMemorySize = MibScalar((1, 3, 6, 1, 2, 1, 25, 2, 2), KBytes()).setUnits('KBytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: hrMemorySize.setDescription('The amount of physical read-write main memory,\n           typically RAM, contained by the host.')
hrStorageTable = MibTable((1, 3, 6, 1, 2, 1, 25, 2, 3), )
if mibBuilder.loadTexts: hrStorageTable.setDescription("The (conceptual) table of logical storage areas on\n           the host.\n\n           An entry shall be placed in the storage table for each\n           logical area of storage that is allocated and has\n           fixed resource limits.  The amount of storage\n           represented in an entity is the amount actually usable\n           by the requesting entity, and excludes loss due to\n           formatting or file system reference information.\n\n           These entries are associated with logical storage\n           areas, as might be seen by an application, rather than\n           physical storage entities which are typically seen by\n           an operating system.  Storage such as tapes and\n           floppies without file systems on them are typically\n           not allocated in chunks by the operating system to\n           requesting applications, and therefore shouldn't\n           appear in this table.  Examples of valid storage for\n           this table include disk partitions, file systems, ram\n           (for some architectures this is further segmented into\n           regular memory, extended memory, and so on), backing\n           store for virtual memory (`swap space').\n\n           This table is intended to be a useful diagnostic for\n           `out of memory' and `out of buffers' types of\n           failures.  In addition, it can be a useful performance\n           monitoring tool for tracking memory, disk, or buffer\n           usage.")
hrStorageEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 2, 3, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrStorageIndex"))
if mibBuilder.loadTexts: hrStorageEntry.setDescription('A (conceptual) entry for one logical storage area on\n           the host.  As an example, an instance of the\n           hrStorageType object might be named hrStorageType.3')
hrStorageIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 2, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrStorageIndex.setDescription('A unique value for each logical storage area\n           contained by the host.')
hrStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 2, 3, 1, 2), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrStorageType.setDescription('The type of storage represented by this entry.')
hrStorageDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 2, 3, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrStorageDescr.setDescription('A description of the type and instance of the storage\n           described by this entry.')
hrStorageAllocationUnits = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 2, 3, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('Bytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: hrStorageAllocationUnits.setDescription('The size, in bytes, of the data objects allocated\n           from this pool.  If this entry is monitoring sectors,\n           blocks, buffers, or packets, for example, this number\n           will commonly be greater than one.  Otherwise this\n           number will typically be one.')
hrStorageSize = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 2, 3, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hrStorageSize.setDescription('The size of the storage represented by this entry, in\n           units of hrStorageAllocationUnits. This object is\n           writable to allow remote configuration of the size of\n           the storage area in those cases where such an\n           operation makes sense and is possible on the\n           underlying system. For example, the amount of main\n           memory allocated to a buffer pool might be modified or\n           the amount of disk space allocated to virtual memory\n           might be modified.')
hrStorageUsed = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 2, 3, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrStorageUsed.setDescription('The amount of the storage represented by this entry\n           that is allocated, in units of\n           hrStorageAllocationUnits.')
hrStorageAllocationFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 2, 3, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrStorageAllocationFailures.setDescription('The number of requests for storage represented by\n           this entry that could not be honored due to not enough\n           storage.  It should be noted that as this object has a\n           SYNTAX of Counter32, that it does not have a defined\n           initial value.  However, it is recommended that this\n           object be initialized to zero, even though management\n           stations must not depend on such an initialization.')
hrDeviceTypes = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 3, 1))
hrDeviceTable = MibTable((1, 3, 6, 1, 2, 1, 25, 3, 2), )
if mibBuilder.loadTexts: hrDeviceTable.setDescription('The (conceptual) table of devices contained by the\n           host.')
hrDeviceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 3, 2, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"))
if mibBuilder.loadTexts: hrDeviceEntry.setDescription('A (conceptual) entry for one device contained by the\n           host.  As an example, an instance of the hrDeviceType\n           object might be named hrDeviceType.3')
hrDeviceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDeviceIndex.setDescription('A unique value for each device contained by the host.\n           The value for each device must remain constant at\n           least from one re-initialization of the agent to the\n           next re-initialization.')
hrDeviceType = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 2, 1, 2), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDeviceType.setDescription("An indication of the type of device.\n\n           If this value is\n           `hrDeviceProcessor { hrDeviceTypes 3 }' then an entry\n           exists in the hrProcessorTable which corresponds to\n           this device.\n\n           If this value is\n           `hrDeviceNetwork { hrDeviceTypes 4 }', then an entry\n           exists in the hrNetworkTable which corresponds to this\n           device.\n\n           If this value is\n           `hrDevicePrinter { hrDeviceTypes 5 }', then an entry\n           exists in the hrPrinterTable which corresponds to this\n           device.\n\n           If this value is\n           `hrDeviceDiskStorage { hrDeviceTypes 6 }', then an\n           entry exists in the hrDiskStorageTable which\n           corresponds to this device.")
hrDeviceDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 2, 1, 3), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,64))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDeviceDescr.setDescription("A textual description of this device, including the\n           device's manufacturer and revision, and optionally,\n           its serial number.")
hrDeviceID = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 2, 1, 4), ProductID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDeviceID.setDescription('The product ID for this device.')
hrDeviceStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 2, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("unknown", 1), ("running", 2), ("warning", 3), ("testing", 4), ("down", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDeviceStatus.setDescription("The current operational state of the device described\n           by this row of the table.  A value unknown(1)\n           indicates that the current state of the device is\n           unknown.  running(2) indicates that the device is up\n           and running and that no unusual error conditions are\n           known.  The warning(3) state indicates that agent has\n           been informed of an unusual error condition by the\n           operational software (e.g., a disk device driver) but\n           that the device is still 'operational'.  An example\n           would be a high number of soft errors on a disk.  A\n           value of testing(4), indicates that the device is not\n           available for use because it is in the testing state.\n           The state of down(5) is used only when the agent has\n           been informed that the device is not available for any\n           use.")
hrDeviceErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDeviceErrors.setDescription('The number of errors detected on this device.  It\n           should be noted that as this object has a SYNTAX of\n           Counter32, that it does not have a defined initial\n           value.  However, it is recommended that this object be\n           initialized to zero, even though management stations\n           must not depend on such an initialization.')
hrProcessorTable = MibTable((1, 3, 6, 1, 2, 1, 25, 3, 3), )
if mibBuilder.loadTexts: hrProcessorTable.setDescription("The (conceptual) table of processors contained by the\n           host.\n\n           Note that this table is potentially sparse: a\n           (conceptual) entry exists only if the correspondent\n           value of the hrDeviceType object is\n           `hrDeviceProcessor'.")
hrProcessorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 3, 3, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"))
if mibBuilder.loadTexts: hrProcessorEntry.setDescription('A (conceptual) entry for one processor contained by\n           the host.  The hrDeviceIndex in the index represents\n           the entry in the hrDeviceTable that corresponds to the\n           hrProcessorEntry.\n\n           As an example of how objects in this table are named,\n           an instance of the hrProcessorFrwID object might be\n           named hrProcessorFrwID.3')
hrProcessorFrwID = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 3, 1, 1), ProductID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrProcessorFrwID.setDescription('The product ID of the firmware associated with the\n           processor.')
hrProcessorLoad = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 3, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,100))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrProcessorLoad.setDescription('The average, over the last minute, of the percentage\n           of time that this processor was not idle.\n           Implementations may approximate this one minute\n           smoothing period if necessary.')
hrNetworkTable = MibTable((1, 3, 6, 1, 2, 1, 25, 3, 4), )
if mibBuilder.loadTexts: hrNetworkTable.setDescription("The (conceptual) table of network devices contained\n           by the host.\n\n\n           Note that this table is potentially sparse: a\n           (conceptual) entry exists only if the correspondent\n           value of the hrDeviceType object is\n           `hrDeviceNetwork'.")
hrNetworkEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 3, 4, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"))
if mibBuilder.loadTexts: hrNetworkEntry.setDescription('A (conceptual) entry for one network device contained\n           by the host.  The hrDeviceIndex in the index\n           represents the entry in the hrDeviceTable that\n           corresponds to the hrNetworkEntry.\n\n           As an example of how objects in this table are named,\n           an instance of the hrNetworkIfIndex object might be\n           named hrNetworkIfIndex.3')
hrNetworkIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 4, 1, 1), InterfaceIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrNetworkIfIndex.setDescription('The value of ifIndex which corresponds to this\n           network device. If this device is not represented in\n           the ifTable, then this value shall be zero.')
hrPrinterTable = MibTable((1, 3, 6, 1, 2, 1, 25, 3, 5), )
if mibBuilder.loadTexts: hrPrinterTable.setDescription("The (conceptual) table of printers local to the host.\n\n           Note that this table is potentially sparse: a\n           (conceptual) entry exists only if the correspondent\n           value of the hrDeviceType object is\n           `hrDevicePrinter'.")
hrPrinterEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 3, 5, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"))
if mibBuilder.loadTexts: hrPrinterEntry.setDescription('A (conceptual) entry for one printer local to the\n           host.  The hrDeviceIndex in the index represents the\n           entry in the hrDeviceTable that corresponds to the\n           hrPrinterEntry.\n\n           As an example of how objects in this table are named,\n           an instance of the hrPrinterStatus object might be\n           named hrPrinterStatus.3')
hrPrinterStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 5, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("unknown", 2), ("idle", 3), ("printing", 4), ("warmup", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrPrinterStatus.setDescription('The current status of this printer device.')
hrPrinterDetectedErrorState = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 5, 1, 2), OctetString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrPrinterDetectedErrorState.setDescription('This object represents any error conditions detected\n           by the printer.  The error conditions are encoded as\n           bits in an octet string, with the following\n           definitions:\n\n                Condition         Bit #\n\n                lowPaper              0\n\n\n                noPaper               1\n                lowToner              2\n                noToner               3\n                doorOpen              4\n                jammed                5\n                offline               6\n                serviceRequested      7\n                inputTrayMissing      8\n                outputTrayMissing     9\n                markerSupplyMissing  10\n                outputNearFull       11\n                outputFull           12\n                inputTrayEmpty       13\n                overduePreventMaint  14\n\n           Bits are numbered starting with the most significant\n           bit of the first byte being bit 0, the least\n           significant bit of the first byte being bit 7, the\n           most significant bit of the second byte being bit 8,\n           and so on.  A one bit encodes that the condition was\n           detected, while a zero bit encodes that the condition\n           was not detected.\n\n           This object is useful for alerting an operator to\n           specific warning or error conditions that may occur,\n           especially those requiring human intervention.')
hrDiskStorageTable = MibTable((1, 3, 6, 1, 2, 1, 25, 3, 6), )
if mibBuilder.loadTexts: hrDiskStorageTable.setDescription("The (conceptual) table of long-term storage devices\n           contained by the host.  In particular, disk devices\n           accessed remotely over a network are not included\n           here.\n\n           Note that this table is potentially sparse: a\n           (conceptual) entry exists only if the correspondent\n           value of the hrDeviceType object is\n           `hrDeviceDiskStorage'.")
hrDiskStorageEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 3, 6, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"))
if mibBuilder.loadTexts: hrDiskStorageEntry.setDescription('A (conceptual) entry for one long-term storage device\n           contained by the host.  The hrDeviceIndex in the index\n           represents the entry in the hrDeviceTable that\n           corresponds to the hrDiskStorageEntry. As an example,\n           an instance of the hrDiskStorageCapacity object might\n           be named hrDiskStorageCapacity.3')
hrDiskStorageAccess = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 6, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("readWrite", 1), ("readOnly", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDiskStorageAccess.setDescription('An indication if this long-term storage device is\n           readable and writable or only readable.  This should\n           reflect the media type, any write-protect mechanism,\n           and any device configuration that affects the entire\n           device.')
hrDiskStorageMedia = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 6, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8,))).clone(namedValues=NamedValues(("other", 1), ("unknown", 2), ("hardDisk", 3), ("floppyDisk", 4), ("opticalDiskROM", 5), ("opticalDiskWORM", 6), ("opticalDiskRW", 7), ("ramDisk", 8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDiskStorageMedia.setDescription('An indication of the type of media used in this long-\n           term storage device.')
hrDiskStorageRemoveble = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 6, 1, 3), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDiskStorageRemoveble.setDescription('Denotes whether or not the disk media may be removed\n           from the drive.')
hrDiskStorageCapacity = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 6, 1, 4), KBytes()).setUnits('KBytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: hrDiskStorageCapacity.setDescription('The total size for this long-term storage device. If\n           the media is removable and is currently removed, this\n           value should be zero.')
hrPartitionTable = MibTable((1, 3, 6, 1, 2, 1, 25, 3, 7), )
if mibBuilder.loadTexts: hrPartitionTable.setDescription('The (conceptual) table of partitions for long-term\n           storage devices contained by the host.  In particular,\n           partitions accessed remotely over a network are not\n           included here.')
hrPartitionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 3, 7, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrDeviceIndex"), (0, "HOST-RESOURCES-MIB", "hrPartitionIndex"))
if mibBuilder.loadTexts: hrPartitionEntry.setDescription('A (conceptual) entry for one partition.  The\n           hrDeviceIndex in the index represents the entry in the\n           hrDeviceTable that corresponds to the\n           hrPartitionEntry.\n\n           As an example of how objects in this table are named,\n           an instance of the hrPartitionSize object might be\n           named hrPartitionSize.3.1')
hrPartitionIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 7, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrPartitionIndex.setDescription('A unique value for each partition on this long-term\n           storage device.  The value for each long-term storage\n           device must remain constant at least from one re-\n           initialization of the agent to the next re-\n           initialization.')
hrPartitionLabel = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 7, 1, 2), InternationalDisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrPartitionLabel.setDescription('A textual description of this partition.')
hrPartitionID = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 7, 1, 3), OctetString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrPartitionID.setDescription('A descriptor which uniquely represents this partition\n           to the responsible operating system.  On some systems,\n           this might take on a binary representation.')
hrPartitionSize = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 7, 1, 4), KBytes()).setUnits('KBytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: hrPartitionSize.setDescription('The size of this partition.')
hrPartitionFSIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 7, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrPartitionFSIndex.setDescription('The index of the file system mounted on this\n           partition.  If no file system is mounted on this\n           partition, then this value shall be zero.  Note that\n           multiple partitions may point to one file system,\n           denoting that that file system resides on those\n           partitions.  Multiple file systems may not reside on\n           one partition.')
hrFSTypes = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 3, 9))
hrFSTable = MibTable((1, 3, 6, 1, 2, 1, 25, 3, 8), )
if mibBuilder.loadTexts: hrFSTable.setDescription("The (conceptual) table of file systems local to this\n           host or remotely mounted from a file server.  File\n           systems that are in only one user's environment on a\n           multi-user system will not be included in this table.")
hrFSEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 3, 8, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrFSIndex"))
if mibBuilder.loadTexts: hrFSEntry.setDescription("A (conceptual) entry for one file system local to\n           this host or remotely mounted from a file server.\n           File systems that are in only one user's environment\n           on a multi-user system will not be included in this\n           table.\n\n           As an example of how objects in this table are named,\n           an instance of the hrFSMountPoint object might be\n           named hrFSMountPoint.3")
hrFSIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrFSIndex.setDescription('A unique value for each file system local to this\n           host.  The value for each file system must remain\n           constant at least from one re-initialization of the\n           agent to the next re-initialization.')
hrFSMountPoint = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 2), InternationalDisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrFSMountPoint.setDescription('The path name of the root of this file system.')
hrFSRemoteMountPoint = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 3), InternationalDisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrFSRemoteMountPoint.setDescription('A description of the name and/or address of the\n           server that this file system is mounted from.  This\n           may also include parameters such as the mount point on\n           the remote file system.  If this is not a remote file\n           system, this string should have a length of zero.')
hrFSType = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 4), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrFSType.setDescription('The value of this object identifies the type of this\n           file system.')
hrFSAccess = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("readWrite", 1), ("readOnly", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrFSAccess.setDescription('An indication if this file system is logically\n           configured by the operating system to be readable and\n           writable or only readable.  This does not represent\n           any local access-control policy, except one that is\n           applied to the file system as a whole.')
hrFSBootable = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 6), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrFSBootable.setDescription('A flag indicating whether this file system is\n           bootable.')
hrFSStorageIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrFSStorageIndex.setDescription('The index of the hrStorageEntry that represents\n           information about this file system.  If there is no\n           such information available, then this value shall be\n           zero.  The relevant storage entry will be useful in\n           tracking the percent usage of this file system and\n           diagnosing errors that may occur when it runs out of\n           space.')
hrFSLastFullBackupDate = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 8), DateAndTime()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hrFSLastFullBackupDate.setDescription("The last date at which this complete file system was\n\n\n           copied to another storage device for backup.  This\n           information is useful for ensuring that backups are\n           being performed regularly.\n\n           If this information is not known, then this variable\n           shall have the value corresponding to January 1, year\n           0000, 00:00:00.0, which is encoded as\n           (hex)'00 00 01 01 00 00 00 00'.")
hrFSLastPartialBackupDate = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 3, 8, 1, 9), DateAndTime()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hrFSLastPartialBackupDate.setDescription("The last date at which a portion of this file system\n           was copied to another storage device for backup.  This\n           information is useful for ensuring that backups are\n           being performed regularly.\n\n           If this information is not known, then this variable\n           shall have the value corresponding to January 1, year\n           0000, 00:00:00.0, which is encoded as\n           (hex)'00 00 01 01 00 00 00 00'.")
hrSWOSIndex = MibScalar((1, 3, 6, 1, 2, 1, 25, 4, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWOSIndex.setDescription('The value of the hrSWRunIndex for the hrSWRunEntry\n           that represents the primary operating system running\n           on this host.  This object is useful for quickly and\n           uniquely identifying that primary operating system.')
hrSWRunTable = MibTable((1, 3, 6, 1, 2, 1, 25, 4, 2), )
if mibBuilder.loadTexts: hrSWRunTable.setDescription('The (conceptual) table of software running on the\n           host.')
hrSWRunEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 4, 2, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrSWRunIndex"))
if mibBuilder.loadTexts: hrSWRunEntry.setDescription('A (conceptual) entry for one piece of software\n           running on the host Note that because the installed\n           software table only contains information for software\n           stored locally on this host, not every piece of\n           running software will be found in the installed\n           software table.  This is true of software that was\n           loaded and run from a non-local source, such as a\n           network-mounted file system.\n\n           As an example of how objects in this table are named,\n           an instance of the hrSWRunName object might be named\n           hrSWRunName.1287')
hrSWRunIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 4, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWRunIndex.setDescription("A unique value for each piece of software running on\n           the host.  Wherever possible, this should be the\n           system's native, unique identification number.")
hrSWRunName = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 4, 2, 1, 2), InternationalDisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,64))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWRunName.setDescription('A textual description of this running piece of\n           software, including the manufacturer, revision,  and\n           the name by which it is commonly known.  If this\n           software was installed locally, this should be the\n           same string as used in the corresponding\n           hrSWInstalledName.')
hrSWRunID = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 4, 2, 1, 3), ProductID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWRunID.setDescription('The product ID of this running piece of software.')
hrSWRunPath = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 4, 2, 1, 4), InternationalDisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWRunPath.setDescription('A description of the location on long-term storage\n           (e.g. a disk drive) from which this software was\n           loaded.')
hrSWRunParameters = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 4, 2, 1, 5), InternationalDisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWRunParameters.setDescription('A description of the parameters supplied to this\n           software when it was initially loaded.')
hrSWRunType = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 4, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("unknown", 1), ("operatingSystem", 2), ("deviceDriver", 3), ("application", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWRunType.setDescription('The type of this software.')
hrSWRunStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 4, 2, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("running", 1), ("runnable", 2), ("notRunnable", 3), ("invalid", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: hrSWRunStatus.setDescription('The status of this running piece of software.\n           Setting this value to invalid(4) shall cause this\n           software to stop running and to be unloaded. Sets to\n           other values are not valid.')
hrSWRunPerfTable = MibTable((1, 3, 6, 1, 2, 1, 25, 5, 1), )
if mibBuilder.loadTexts: hrSWRunPerfTable.setDescription('The (conceptual) table of running software\n           performance metrics.')
hrSWRunPerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 5, 1, 1), )
hrSWRunEntry.registerAugmentions(("HOST-RESOURCES-MIB", "hrSWRunPerfEntry"))
hrSWRunPerfEntry.setIndexNames(*hrSWRunEntry.getIndexNames())
if mibBuilder.loadTexts: hrSWRunPerfEntry.setDescription('A (conceptual) entry containing software performance\n           metrics.  As an example, an instance of the\n           hrSWRunPerfCPU object might be named\n           hrSWRunPerfCPU.1287')
hrSWRunPerfCPU = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 5, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWRunPerfCPU.setDescription("The number of centi-seconds of the total system's CPU\n           resources consumed by this process.  Note that on a\n           multi-processor system, this value may increment by\n           more than one centi-second in one centi-second of real\n           (wall clock) time.")
hrSWRunPerfMem = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 5, 1, 1, 2), KBytes()).setUnits('KBytes').setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWRunPerfMem.setDescription('The total amount of real system memory allocated to\n           this process.')
hrSWInstalledLastChange = MibScalar((1, 3, 6, 1, 2, 1, 25, 6, 1), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWInstalledLastChange.setDescription('The value of sysUpTime when an entry in the\n           hrSWInstalledTable was last added, renamed, or\n           deleted.  Because this table is likely to contain many\n           entries, polling of this object allows a management\n           station to determine when re-downloading of the table\n           might be useful.')
hrSWInstalledLastUpdateTime = MibScalar((1, 3, 6, 1, 2, 1, 25, 6, 2), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWInstalledLastUpdateTime.setDescription('The value of sysUpTime when the hrSWInstalledTable\n           was last completely updated.  Because caching of this\n           data will be a popular implementation strategy,\n           retrieval of this object allows a management station\n           to obtain a guarantee that no data in this table is\n           older than the indicated time.')
hrSWInstalledTable = MibTable((1, 3, 6, 1, 2, 1, 25, 6, 3), )
if mibBuilder.loadTexts: hrSWInstalledTable.setDescription('The (conceptual) table of software installed on this\n           host.')
hrSWInstalledEntry = MibTableRow((1, 3, 6, 1, 2, 1, 25, 6, 3, 1), ).setIndexNames((0, "HOST-RESOURCES-MIB", "hrSWInstalledIndex"))
if mibBuilder.loadTexts: hrSWInstalledEntry.setDescription('A (conceptual) entry for a piece of software\n           installed on this host.\n\n           As an example of how objects in this table are named,\n           an instance of the hrSWInstalledName object might be\n           named hrSWInstalledName.96')
hrSWInstalledIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 6, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWInstalledIndex.setDescription('A unique value for each piece of software installed\n           on the host.  This value shall be in the range from 1\n           to the number of pieces of software installed on the\n           host.')
hrSWInstalledName = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 6, 3, 1, 2), InternationalDisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,64))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWInstalledName.setDescription('A textual description of this installed piece of\n           software, including the manufacturer, revision, the\n           name by which it is commonly known, and optionally,\n           its serial number.')
hrSWInstalledID = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 6, 3, 1, 3), ProductID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWInstalledID.setDescription('The product ID of this installed piece of software.')
hrSWInstalledType = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 6, 3, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("unknown", 1), ("operatingSystem", 2), ("deviceDriver", 3), ("application", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWInstalledType.setDescription('The type of this software.')
hrSWInstalledDate = MibTableColumn((1, 3, 6, 1, 2, 1, 25, 6, 3, 1, 5), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hrSWInstalledDate.setDescription("The last-modification date of this application as it\n           would appear in a directory listing.\n\n           If this information is not known, then this variable\n           shall have the value corresponding to January 1, year\n           0000, 00:00:00.0, which is encoded as\n           (hex)'00 00 01 01 00 00 00 00'.")
hrMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 7, 2))
hrMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 25, 7, 3))
hrMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 25, 7, 2, 1)).setObjects(*(("HOST-RESOURCES-MIB", "hrSystemGroup"), ("HOST-RESOURCES-MIB", "hrStorageGroup"), ("HOST-RESOURCES-MIB", "hrDeviceGroup"),))
if mibBuilder.loadTexts: hrMIBCompliance.setDescription('The requirements for conformance to the Host Resources MIB.')
hrSystemGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 25, 7, 3, 1)).setObjects(*(("HOST-RESOURCES-MIB", "hrSystemUptime"), ("HOST-RESOURCES-MIB", "hrSystemDate"), ("HOST-RESOURCES-MIB", "hrSystemInitialLoadDevice"), ("HOST-RESOURCES-MIB", "hrSystemInitialLoadParameters"), ("HOST-RESOURCES-MIB", "hrSystemNumUsers"), ("HOST-RESOURCES-MIB", "hrSystemProcesses"), ("HOST-RESOURCES-MIB", "hrSystemMaxProcesses"),))
if mibBuilder.loadTexts: hrSystemGroup.setDescription('The Host Resources System Group.')
hrStorageGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 25, 7, 3, 2)).setObjects(*(("HOST-RESOURCES-MIB", "hrMemorySize"), ("HOST-RESOURCES-MIB", "hrStorageIndex"), ("HOST-RESOURCES-MIB", "hrStorageType"), ("HOST-RESOURCES-MIB", "hrStorageDescr"), ("HOST-RESOURCES-MIB", "hrStorageAllocationUnits"), ("HOST-RESOURCES-MIB", "hrStorageSize"), ("HOST-RESOURCES-MIB", "hrStorageUsed"), ("HOST-RESOURCES-MIB", "hrStorageAllocationFailures"),))
if mibBuilder.loadTexts: hrStorageGroup.setDescription('The Host Resources Storage Group.')
hrDeviceGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 25, 7, 3, 3)).setObjects(*(("HOST-RESOURCES-MIB", "hrDeviceIndex"), ("HOST-RESOURCES-MIB", "hrDeviceType"), ("HOST-RESOURCES-MIB", "hrDeviceDescr"), ("HOST-RESOURCES-MIB", "hrDeviceID"), ("HOST-RESOURCES-MIB", "hrDeviceStatus"), ("HOST-RESOURCES-MIB", "hrDeviceErrors"), ("HOST-RESOURCES-MIB", "hrProcessorFrwID"), ("HOST-RESOURCES-MIB", "hrProcessorLoad"), ("HOST-RESOURCES-MIB", "hrNetworkIfIndex"), ("HOST-RESOURCES-MIB", "hrPrinterStatus"), ("HOST-RESOURCES-MIB", "hrPrinterDetectedErrorState"), ("HOST-RESOURCES-MIB", "hrDiskStorageAccess"), ("HOST-RESOURCES-MIB", "hrDiskStorageMedia"), ("HOST-RESOURCES-MIB", "hrDiskStorageRemoveble"), ("HOST-RESOURCES-MIB", "hrDiskStorageCapacity"), ("HOST-RESOURCES-MIB", "hrPartitionIndex"), ("HOST-RESOURCES-MIB", "hrPartitionLabel"), ("HOST-RESOURCES-MIB", "hrPartitionID"), ("HOST-RESOURCES-MIB", "hrPartitionSize"), ("HOST-RESOURCES-MIB", "hrPartitionFSIndex"), ("HOST-RESOURCES-MIB", "hrFSIndex"), ("HOST-RESOURCES-MIB", "hrFSMountPoint"), ("HOST-RESOURCES-MIB", "hrFSRemoteMountPoint"), ("HOST-RESOURCES-MIB", "hrFSType"), ("HOST-RESOURCES-MIB", "hrFSAccess"), ("HOST-RESOURCES-MIB", "hrFSBootable"), ("HOST-RESOURCES-MIB", "hrFSStorageIndex"), ("HOST-RESOURCES-MIB", "hrFSLastFullBackupDate"), ("HOST-RESOURCES-MIB", "hrFSLastPartialBackupDate"),))
if mibBuilder.loadTexts: hrDeviceGroup.setDescription('The Host Resources Device Group.')
hrSWRunGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 25, 7, 3, 4)).setObjects(*(("HOST-RESOURCES-MIB", "hrSWOSIndex"), ("HOST-RESOURCES-MIB", "hrSWRunIndex"), ("HOST-RESOURCES-MIB", "hrSWRunName"), ("HOST-RESOURCES-MIB", "hrSWRunID"), ("HOST-RESOURCES-MIB", "hrSWRunPath"), ("HOST-RESOURCES-MIB", "hrSWRunParameters"), ("HOST-RESOURCES-MIB", "hrSWRunType"), ("HOST-RESOURCES-MIB", "hrSWRunStatus"),))
if mibBuilder.loadTexts: hrSWRunGroup.setDescription('The Host Resources Running Software Group.')
hrSWRunPerfGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 25, 7, 3, 5)).setObjects(*(("HOST-RESOURCES-MIB", "hrSWRunPerfCPU"), ("HOST-RESOURCES-MIB", "hrSWRunPerfMem"),))
if mibBuilder.loadTexts: hrSWRunPerfGroup.setDescription('The Host Resources Running Software\n               Performance Group.')
hrSWInstalledGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 25, 7, 3, 6)).setObjects(*(("HOST-RESOURCES-MIB", "hrSWInstalledLastChange"), ("HOST-RESOURCES-MIB", "hrSWInstalledLastUpdateTime"), ("HOST-RESOURCES-MIB", "hrSWInstalledIndex"), ("HOST-RESOURCES-MIB", "hrSWInstalledName"), ("HOST-RESOURCES-MIB", "hrSWInstalledID"), ("HOST-RESOURCES-MIB", "hrSWInstalledType"), ("HOST-RESOURCES-MIB", "hrSWInstalledDate"),))
if mibBuilder.loadTexts: hrSWInstalledGroup.setDescription('The Host Resources Installed Software Group.')
mibBuilder.exportSymbols("HOST-RESOURCES-MIB", hrProcessorEntry=hrProcessorEntry, hrDeviceEntry=hrDeviceEntry, hrSWRunPerfTable=hrSWRunPerfTable, hrSWRunPerfGroup=hrSWRunPerfGroup, hrMIBCompliances=hrMIBCompliances, hrDiskStorageEntry=hrDiskStorageEntry, hrStorageIndex=hrStorageIndex, hrSWRunPerfMem=hrSWRunPerfMem, hrDeviceIndex=hrDeviceIndex, hrFSTypes=hrFSTypes, hrSystemNumUsers=hrSystemNumUsers, hrSystemGroup=hrSystemGroup, hrSWRunPerfCPU=hrSWRunPerfCPU, hrPrinterEntry=hrPrinterEntry, hrMemorySize=hrMemorySize, hrDeviceStatus=hrDeviceStatus, hrStorageAllocationUnits=hrStorageAllocationUnits, hrFSIndex=hrFSIndex, hrDiskStorageAccess=hrDiskStorageAccess, hrDiskStorageCapacity=hrDiskStorageCapacity, hrSystemProcesses=hrSystemProcesses, hrDeviceType=hrDeviceType, hrSWRunEntry=hrSWRunEntry, hrStorageType=hrStorageType, hrStorageSize=hrStorageSize, hrSystemDate=hrSystemDate, hrSystemUptime=hrSystemUptime, hrDeviceTypes=hrDeviceTypes, PYSNMP_MODULE_ID=hostResourcesMibModule, hrDevice=hrDevice, hrNetworkEntry=hrNetworkEntry, hrSWInstalledEntry=hrSWInstalledEntry, hrSWInstalledGroup=hrSWInstalledGroup, hrPartitionFSIndex=hrPartitionFSIndex, hrStorageEntry=hrStorageEntry, hrStorageTable=hrStorageTable, hrSWInstalledType=hrSWInstalledType, hrStorageUsed=hrStorageUsed, hostResourcesMibModule=hostResourcesMibModule, hrSWRunName=hrSWRunName, hrSystem=hrSystem, hrFSLastPartialBackupDate=hrFSLastPartialBackupDate, hrSystemInitialLoadDevice=hrSystemInitialLoadDevice, hrSystemMaxProcesses=hrSystemMaxProcesses, hrSWRunTable=hrSWRunTable, hrSWInstalledDate=hrSWInstalledDate, hrPartitionTable=hrPartitionTable, hrProcessorFrwID=hrProcessorFrwID, hrDiskStorageTable=hrDiskStorageTable, hrSWRun=hrSWRun, hrSWRunGroup=hrSWRunGroup, hrSWRunPerf=hrSWRunPerf, hrNetworkIfIndex=hrNetworkIfIndex, hrSWInstalledIndex=hrSWInstalledIndex, hrFSBootable=hrFSBootable, host=host, hrPrinterDetectedErrorState=hrPrinterDetectedErrorState, hrStorageDescr=hrStorageDescr, hrDeviceDescr=hrDeviceDescr, hrSWInstalledLastUpdateTime=hrSWInstalledLastUpdateTime, ProductID=ProductID, hrMIBAdminInfo=hrMIBAdminInfo, hrFSTable=hrFSTable, hrSWInstalledTable=hrSWInstalledTable, hrDeviceErrors=hrDeviceErrors, hrFSRemoteMountPoint=hrFSRemoteMountPoint, hrFSEntry=hrFSEntry, hrFSLastFullBackupDate=hrFSLastFullBackupDate, hrPartitionLabel=hrPartitionLabel, hrMIBCompliance=hrMIBCompliance, hrFSMountPoint=hrFSMountPoint, hrDeviceID=hrDeviceID, hrStorageAllocationFailures=hrStorageAllocationFailures, hrNetworkTable=hrNetworkTable, hrSWInstalled=hrSWInstalled, hrDeviceTable=hrDeviceTable, hrSWRunPerfEntry=hrSWRunPerfEntry, hrFSType=hrFSType, InternationalDisplayString=InternationalDisplayString, hrProcessorTable=hrProcessorTable, hrFSStorageIndex=hrFSStorageIndex, KBytes=KBytes, hrPartitionEntry=hrPartitionEntry, hrSWInstalledName=hrSWInstalledName, hrSWRunIndex=hrSWRunIndex, hrProcessorLoad=hrProcessorLoad, hrSWRunType=hrSWRunType, hrSWRunID=hrSWRunID, hrStorageTypes=hrStorageTypes, hrPrinterTable=hrPrinterTable, hrStorageGroup=hrStorageGroup, hrSWInstalledID=hrSWInstalledID, hrSWRunPath=hrSWRunPath, hrFSAccess=hrFSAccess, hrSWOSIndex=hrSWOSIndex, hrSWRunParameters=hrSWRunParameters, hrPartitionSize=hrPartitionSize, hrPartitionIndex=hrPartitionIndex, hrMIBGroups=hrMIBGroups, hrPrinterStatus=hrPrinterStatus, hrSWRunStatus=hrSWRunStatus, hrPartitionID=hrPartitionID, hrSystemInitialLoadParameters=hrSystemInitialLoadParameters, hrSWInstalledLastChange=hrSWInstalledLastChange, hrDiskStorageMedia=hrDiskStorageMedia, hrDeviceGroup=hrDeviceGroup, hrDiskStorageRemoveble=hrDiskStorageRemoveble, hrStorage=hrStorage)
